@@ -21,7 +21,7 @@ class StatsViewMixin:
             qs = self.add_stats_to_queryset(queryset=qs)
         return qs
 
-    def get_serializer_class(self):
+    def get_response_serializer_class(self):
         klass = getattr(self, 'serializer_stats_class', None)
         if not klass or not self.with_stats:
             klass = super().get_serializer_class()
